==> tine20-allinone_2019.12.5.tar.bz2: Tasks/js/Tasks-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fi\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Tehtävä"
 ,"Tehtävät"

]
, "Percent"
: "Prosenttia"

, "Completed"
: "Valmis"

, "Due"
: "Määräpäivä"

, "Class"
: ""

, "Description"
: "Kuvaus"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Järjestäjä"

, "Priority"
: "Tärkeys"

, "Status, Status"
: [
  "Tila"
 ,"Tilat"

]
, "Lead"
: "Vainu"

, "Telephone"
: "Puhelin"

, "Email"
: "Sähköposti"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Määritä määräpäivä koska hälytys on asetettu!"

, "Summary"
: "Yhteeneveto"

, "Due date"
: "Määräpäivä"

, "Add Responsible ..."
: "Lisää vastuuhenkilö ..."

, "Notes"
: "Huomautukset"

, "Enter description..."
: "Lisää kuvaus...."

, "Percentage"
: "Prosenttia"

, "Tasks"
: "Tehtävät"

, "to do list, to do lists"
: [
  "tehtävälista"
 ,"tehtävälistat"

]
, "to do lists"
: "tehtävälista"

, "Quick Search"
: ""

, "Due Date"
: "Määräpäivä"

, "Responsible"
: "Vastuuhenkilö"

, "Last Modified Time"
: "Muokattu viimeksi"

, "Last Modified By"
: "Muokannut viimeksi"

, "Creation Time"
: "Luontiaika"

, "Created By"
: "Luonut"

, "New Task"
: "Uusi tehtävä"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Haluatko poistaa valitun tehtävän?"
 ,"Haluatko poistaa valitut tehtävät?"

]
, "Attachments"
: ""

, "Tags"
: "Tagit"

, "Lead name"
: ""

, "Add a task..."
: "Lisää tehtävä..."

, "All my tasks"
: "Kaikki tehtäväni"

, "Default Favorite"
: "Oletus suosikki"

, "The default favorite which is loaded on Tasks startup"
: "Oletus suosikki joka ladataan käynnistettäessä"

, "Default Task List"
: "Oletus tehtävälista"

, "The default task list to create new tasks in."
: "Lista, johon uudet tehtävät luodaan oletusarvoisesti."

, "Tasks status available"
: "Tehtävien tila saatavilla"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Mahdolliset tehtävän vaiheet. Huomaathan, että lisätyt vaiheet eivät välttämättä välity oikein toisiin tehtävänhallintajärjestelmiin."

, "No response"
: "Ei vastausta"

, "Cancelled"
: "Peruutettu"

, "In process"
: "Työn alla"

, "Task priorities available"
: "Tehtävien tärkeysjärjestys saatavilla"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Mahdolliset prioriteetit, joita tehtävälle voi antaa. Huomaathan, että lisätyt prioriteetit eivät välttämättä välity oikein toisiin tehtävänhallintajärjestelmiin."

, "low"
: "alhainen"

, "normal"
: "normaali"

, "high"
: "korkea"

, "urgent"
: "tärkeä"

, "manage shared task lists"
: "hallitse jaettua tehtävää"

, "Create new shared tasks lists"
: "Luo uusi jaettu tehtävä"

, "manage shared tasks favorites"
: "hallitse jaetun tehtävän suosikkeja"

, "Create or update shared tasks favorites"
: "Luo tai päivitä jaettujen tehtävien suosikkeja"

, "%s's personal tasks"
: "%s's henkilökohtaisia tehtäviä"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Oman tehtävälistan tehtävät"

, "My open tasks"
: "Avoimet tehtäväni"

, "My open tasks this week"
: "Avoimet tehtäväni tällä viikolla"

, "All tasks for me"
: "Kaikki tehtäväni"

, "All tasks that I am responsible for"
: "Tehtävät, joissa olen vastuuhenkilö"

, "Last modified by me"
: "Edellinen muokkaukseni"

, "All tasks that I have last modified"
: "Kaikki tehtävät joita olen muokannut"

, "Tasks without responsible"
: "Tehtävä ilman vastausta"

, "GENDER_Task"
: ""

, "Task"
: "Tehtävä"

, "Status"
: "Tila"

, "to do list"
: "tehtävälista"

, "Do you really want to delete the selected task?"
: "Haluatko poistaa valitun tehtävän?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Määritä määräpäivä koska hälytys on asetettu!"

, "Summary"
: "Yhteeneveto"

, "Due date"
: "Määräpäivä"

, "Priority"
: "Tärkeys"

, "Organizer"
: "Järjestäjä"

, "Add Responsible ..."
: "Lisää vastuuhenkilö ..."

, "Notes"
: "Huomautukset"

, "Enter description..."
: "Lisää kuvaus...."

, "Percentage"
: "Prosenttia"

, "Status, Status"
: [
  "Tila"
 ,"Tilat"

]
, "Completed"
: "Valmis"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Haluatko poistaa valitun tehtävän?"
 ,"Haluatko poistaa valitut tehtävät?"

]
, "Attachments"
: ""

, "Tags"
: "Tagit"

, "Lead name"
: ""

, "Add a task..."
: "Lisää tehtävä..."

, "Due Date"
: "Määräpäivä"

, "Percent"
: "Prosenttia"

, "Responsible"
: "Vastuuhenkilö"

, "Task, Tasks"
: [
  "Tehtävä"
 ,"Tehtävät"

]
, "Tasks"
: "Tehtävät"

, "to do list, to do lists"
: [
  "tehtävälista"
 ,"tehtävälistat"

]
, "to do lists"
: "tehtävälista"

, "Quick Search"
: ""

, "Last Modified Time"
: "Muokattu viimeksi"

, "Last Modified By"
: "Muokannut viimeksi"

, "Creation Time"
: "Luontiaika"

, "Created By"
: "Luonut"

, "New Task"
: "Uusi tehtävä"

, "All my tasks"
: "Kaikki tehtäväni"

, "Default Favorite"
: "Oletus suosikki"

, "The default favorite which is loaded on Tasks startup"
: "Oletus suosikki joka ladataan käynnistettäessä"

, "Default Task List"
: "Oletus tehtävälista"

, "The default task list to create new tasks in."
: "Lista, johon uudet tehtävät luodaan oletusarvoisesti."

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: "Tehtävien tila saatavilla"

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: "Mahdolliset tehtävän vaiheet. Huomaathan, että lisätyt vaiheet eivät välttämättä välity oikein toisiin tehtävänhallintajärjestelmiin."

, "No response"
: "Ei vastausta"

, "Cancelled"
: "Peruutettu"

, "In process"
: "Työn alla"

, "Task priorities available"
: "Tehtävien tärkeysjärjestys saatavilla"

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: "Mahdolliset prioriteetit, joita tehtävälle voi antaa. Huomaathan, että lisätyt prioriteetit eivät välttämättä välity oikein toisiin tehtävänhallintajärjestelmiin."

, "low"
: "alhainen"

, "normal"
: "normaali"

, "high"
: "korkea"

, "urgent"
: "tärkeä"

, "%s's personal tasks"
: "%s's henkilökohtaisia tehtäviä"

, "GENDER_Task"
: ""

, "Due"
: "Määräpäivä"

, "Class"
: ""

, "Description"
: "Kuvaus"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Vainu"

, "Telephone"
: "Puhelin"

, "Email"
: "Sähköposti"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Oman tehtävälistan tehtävät"

, "My open tasks"
: "Avoimet tehtäväni"

, "My open tasks this week"
: "Avoimet tehtäväni tällä viikolla"

, "All tasks for me"
: "Kaikki tehtäväni"

, "All tasks that I am responsible for"
: "Tehtävät, joissa olen vastuuhenkilö"

, "Last modified by me"
: "Edellinen muokkaukseni"

, "All tasks that I have last modified"
: "Kaikki tehtävät joita olen muokannut"

, "Tasks without responsible"
: "Tehtävä ilman vastausta"

, "manage shared task lists"
: "hallitse jaettua tehtävää"

, "Create new shared tasks lists"
: "Luo uusi jaettu tehtävä"

, "manage shared tasks favorites"
: "hallitse jaetun tehtävän suosikkeja"

, "Create or update shared tasks favorites"
: "Luo tai päivitä jaettujen tehtävien suosikkeja"

, "Status"
: "Tila"

, "Do you really want to delete the selected task?"
: "Haluatko poistaa valitun tehtävän?"

, "Task"
: "Tehtävä"

, "to do list"
: "tehtävälista"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
